summaryrefslogtreecommitdiff
path: root/nova/tests/unit/test_hacking.py
diff options
context:
space:
mode:
authorRajesh Tailor <ratailor@redhat.com>2016-06-09 08:57:58 -0400
committerRajesh Tailor <ratailor@redhat.com>2016-06-13 06:41:08 +0000
commit9ebf9a5aa5bb4cc1381b1b4abcac0c270458c4a0 (patch)
tree5588d0dbc8729447e02c629cf29c4fed201d6e7f /nova/tests/unit/test_hacking.py
parent89e78bf5a6bc98525178aba908880963e3eb10e0 (diff)
downloadnova-9ebf9a5aa5bb4cc1381b1b4abcac0c270458c4a0.tar.gz
Trivial-Fix: Fix typos
Change-Id: I09a87b7a13cf551f18ef1fb27aa9f5406baebab4
Diffstat (limited to 'nova/tests/unit/test_hacking.py')
-rw-r--r--nova/tests/unit/test_hacking.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/nova/tests/unit/test_hacking.py b/nova/tests/unit/test_hacking.py
index 0f80d568f0..d4559de766 100644
--- a/nova/tests/unit/test_hacking.py
+++ b/nova/tests/unit/test_hacking.py
@@ -618,7 +618,7 @@ class HackingTestCase(test.NoDBTestCase):
checks.check_config_option_in_central_place,
filename="nova/conf/serial_console.py")
# option at a location which is not in scope right now
- # TODO(markus_z): This is remporary until all config options are
+ # TODO(markus_z): This is temporary until all config options are
# moved to /nova/conf
self._assert_has_no_errors(code,
checks.check_config_option_in_central_place,
@@ -704,10 +704,10 @@ class HackingTestCase(test.NoDBTestCase):
"""
self._assert_has_no_errors(code6, checks.cfg_help_with_enough_text)
# The help text uses a paranthesis (weird, but produces a valid string)
code7 = """
opt = cfg.StrOpt("opt7",
- help=("help text uses extra paranthesis"))
+ help=("help text uses extra parenthesis"))
"""
self._assert_has_no_errors(code7, checks.cfg_help_with_enough_text)
@@ -704,10 +704,10 @@ class HackingTestCase(test.NoDBTestCase):
"""
self._assert_has_no_errors(code6, checks.cfg_help_with_enough_text)
- # The help text uses a paranthesis (weird, but produces a valid string)
+ # The help text uses a parenthesis (weird, but produces a valid string)
code7 = """
opt = cfg.StrOpt("opt7",